"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var typesafe_actions_1 = require("typesafe-actions");
var actions_1 = require("../actions");
var api = require("../services/api");
var ls = function (action$, state$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.request.ls.request)), operators_1.mergeMap(function () {
        return rxjs_1.from(api.ls(state$.value.ipfs.files.root)).pipe(operators_1.map(actions_1.files.request.ls.success), operators_1.catchError(function (error) { return rxjs_1.of(actions_1.files.request.ls.failure(error)); }));
    }));
};
var watchLs = function (action$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.ls)), operators_1.map(actions_1.files.request.ls.request));
};
var cat = function (action$, state$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.request.cat.request)), operators_1.mergeMap(function (action) {
        return rxjs_1.from(api.cat(state$.value.ipfs.files.root, action.payload)).pipe(operators_1.map(actions_1.files.request.cat.success), operators_1.catchError(function (error) { return rxjs_1.of(actions_1.files.request.cat.failure(error)); }));
    }));
};
var watchCat = function (action$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.cat)), operators_1.map(function (action) { return actions_1.files.request.cat.request(action.payload); }));
};
var rm = function (action$, state$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.request.rm.request)), operators_1.mergeMap(function (action) {
        return rxjs_1.from(api.rm(state$.value.ipfs.files.root, action.payload)).pipe(operators_1.map(actions_1.files.request.rm.success), operators_1.catchError(function (error) { return rxjs_1.of(actions_1.files.request.rm.failure(error)); }));
    }));
};
var watchRm = function (action$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.rm)), operators_1.map(function (action) { return actions_1.files.request.rm.request(action.payload); }));
};
var watchRmSuccess = function (action$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.request.rm.success)), operators_1.map(actions_1.files.ls));
};
var touch = function (action$, state$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.request.touch.request)), operators_1.mergeMap(function (action) {
        return rxjs_1.from(api.touch(state$.value.ipfs.files.root, action.payload.name, action.payload.content)).pipe(operators_1.map(actions_1.files.request.touch.success), operators_1.catchError(function (error) { return rxjs_1.of(actions_1.files.request.touch.failure(error)); }));
    }));
};
var watchTouch = function (action$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.touch)), operators_1.map(function (action) { return actions_1.files.request.touch.request(action.payload); }));
};
var watchTouchSuccess = function (action$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.request.touch.success)), operators_1.map(actions_1.files.ls));
};
var mkdir = function (action$, state$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.request.mkdir.request)), operators_1.mergeMap(function (action) {
        return rxjs_1.from(api.mkdir(state$.value.ipfs.files.root, action.payload)).pipe(operators_1.map(actions_1.files.request.mkdir.success, actions_1.files.ls), operators_1.catchError(function (error) { return rxjs_1.of(actions_1.files.request.mkdir.failure(error)); }));
    }));
};
var watchMkdir = function (action$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.mkdir)), operators_1.map(function (action) { return actions_1.files.request.mkdir.request(action.payload); }));
};
var watchMkdirSuccess = function (action$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.request.mkdir.success)), operators_1.map(actions_1.files.ls));
};
var rmdir = function (action$, state$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.request.rmdir.request)), operators_1.mergeMap(function (action) {
        return rxjs_1.from(api.rm(state$.value.ipfs.files.root, action.payload)).pipe(operators_1.map(actions_1.files.request.rmdir.success, actions_1.files.ls), operators_1.catchError(function (error) { return rxjs_1.of(actions_1.files.request.rmdir.failure(error)); }));
    }));
};
var watchRmdir = function (action$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.rmdir)), operators_1.map(function (action) { return actions_1.files.request.rmdir.request(action.payload); }));
};
var watchRmdirSuccess = function (action$) {
    return action$.pipe(operators_1.filter(typesafe_actions_1.isActionOf(actions_1.files.request.rmdir.success)), operators_1.map(actions_1.files.ls));
};
exports.default = [
    watchLs,
    ls,
    watchCat,
    cat,
    watchRm,
    watchRmSuccess,
    rm,
    watchTouch,
    watchTouchSuccess,
    touch,
    watchMkdir,
    watchMkdirSuccess,
    mkdir,
    watchRmdir,
    watchRmdirSuccess,
    rmdir
];
//# sourceMappingURL=files.js.map