"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var API = require("ipfs-api");
var path = require("path");
var host = process.env.NODE_ENV !== 'production' ? 'localhost' : window.location.hostname;
var port = process.env.NODE_ENV !== 'production' ? '5001' : window.location.port || 80;
var localApi = new API(host, port);
exports.id = localApi.id;
exports.ls = function (root, api) {
    if (api === void 0) { api = localApi; }
    return api.files.ls(root, { l: true });
};
exports.mkdir = function (root, name, api) {
    if (api === void 0) { api = localApi; }
    var target = path.join(root, name);
    return api.files.mkdir(target);
};
exports.rm = function (root, name, api) {
    if (api === void 0) { api = localApi; }
    var target = path.join(root, name);
    return api.files.rm(target, { recursive: true });
};
exports.touch = function (root, name, content, api) {
    if (api === void 0) { api = localApi; }
    var target = path.join(root, name);
    return api.files.write(target, api.Buffer.from(content), { create: true });
};
exports.cat = function (root, name, api) {
    if (api === void 0) { api = localApi; }
    var target = path.join(root, name);
    return api.files
        .read(target)
        .then(function (buffer) { return buffer.toString('utf8'); });
};
//# sourceMappingURL=api.js.map